Serializer

Struct Serializer 

pub struct Serializer { /* private fields */ }
Serializes values into JSON.

Every call to serialize writes a value. What follows the values depends on SerializerConfig::set_trailing: by default only a single value can be written, with Trailing::Newline every value is followed by a line break (JSON Lines).

use deser_hj::{Serializer, SerializerConfig, Trailing};

const LINES: SerializerConfig =
    SerializerConfig::builder().trailing(Trailing::Newline).build();
let mut serializer = Serializer::with_config(LINES);
serializer.serialize(&vec![1, 2]).unwrap();
serializer.serialize(&"x").unwrap();
assert_eq!(serializer.finish(), "[1,2]\n\"x\"\n");

The serializer is also the stream serializer of JSON (see StreamSerializer): the output can be taken while values are written, and large values can be written in parts. To write to a Write use SerializerConfig::writer:

use deser_hj::SerializerConfig;

let mut writer = SerializerConfig::new().writer(Vec::new());
writer.set_buffer_limit(4);
writer.write(&vec!["a", "b", "c"]).unwrap();
assert_eq!(writer.into_inner(), br#"["a","b","c"]"#);

Implementations

Source

impl Serializer

pub fn new() -> Serializer

Creates a serializer.

pub fn with_config(config: SerializerConfig) -> Serializer

Creates a serializer with the given configuration.

pub fn with_written(config: SerializerConfig, written: usize) -> Serializer

Creates a serializer for a stream that continues after the given number of values.

This is useful to append to a stream that was written before (see SerializerConfig::set_trailing for what separates the values).

pub fn config(&self) -> &SerializerConfig

Returns the configuration.

pub fn written(&self) -> usize

Returns the number of values that were written.

pub fn serialize<T: Serialize + ?Sized>( &mut self, value: &T, ) -> Result<(), Error>

Serializes a value.

If the value fails to serialize, nothing is written.

pub fn serialize_with<F, T: Serialize + ?Sized>( &mut self, value: &T, setup: F, ) -> Result<(), Error>
where F: FnOnce(&mut SerializeDriver<'_>),

Serializes a value with a configured driver.

The callback is invoked with the driver before the value is serialized, for instance to add Layers.

pub fn as_str(&self) -> &str

Returns the output written so far (that was not cleared).

pub fn finish(self) -> String

Returns the output.